summaryrefslogtreecommitdiffstats
path: root/kgoldrunner/src/kgrgame.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commita13e26c2f1eb3c5be81acf4f571dd4bafac10199 (patch)
tree1f1d3e407ae668b1448847970b2f1b626083faf6 /kgoldrunner/src/kgrgame.cpp
parent24c5cdc2737fe0044b11a12359606973eb93fc0b (diff)
downloadtdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.tar.gz
tdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kgoldrunner/src/kgrgame.cpp')
-rw-r--r--kgoldrunner/src/kgrgame.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kgoldrunner/src/kgrgame.cpp b/kgoldrunner/src/kgrgame.cpp
index 930bd83f..a52abe01 100644
--- a/kgoldrunner/src/kgrgame.cpp
+++ b/kgoldrunner/src/kgrgame.cpp
@@ -2226,10 +2226,10 @@ bool KGrGame::ownerOK (Owner o)
/********************** CLASS TO DISPLAY THUMBNAIL ***********************/
/******************************************************************************/
-KGrThumbNail::KGrThumbNail (TQWidget * tqparent, const char * name)
- : TQFrame (tqparent, name)
+KGrThumbNail::KGrThumbNail (TQWidget * parent, const char * name)
+ : TQFrame (parent, name)
{
// Let the tqparent do all the work. We need a class here so that
// TQFrame::drawContents (TQPainter *) can be re-implemented and
// the thumbnail can be automatically re-painted when required.
}
@@ -2588,12 +2588,12 @@ bool KGrGame::saveCollections (Owner o)
/********************** WORD-WRAPPED MESSAGE BOX ************************/
/******************************************************************************/
-void KGrGame::myMessage (TQWidget * tqparent, TQString title, TQString contents)
+void KGrGame::myMessage (TQWidget * parent, TQString title, TQString contents)
{
// Halt the game while the message is displayed.
setMessageFreeze (TRUE);
- KGrMessage::wrapped (tqparent, title, contents);
+ KGrMessage::wrapped (parent, title, contents);
// Unfreeze the game, but only if it was previously unfrozen.
setMessageFreeze (FALSE);
@@ -2226,10 +2226,10 @@ bool KGrGame::ownerOK (Owner o)
{
- // Let the tqparent do all the work. We need a class here so that
+ // Let the parent do all the work. We need a class here so that
// TQFrame::drawContents (TQPainter *) can be re-implemented and
// the thumbnail can be automatically re-painted when required.